@@ -25,6 +25,8 @@
 #include "ILexer.h"
 #include "Scintilla.h"
 
+#include "CharacterCategory.h"
+
 #include "Position.h"
 #include "UniqueString.h"
 #include "SplitVector.h"
@@ -48,7 +50,7 @@
 
 using namespace Scintilla;
 
-Caret::Caret() :
+Caret::Caret() noexcept :
 	active(false), on(false), period(500) {}
 
 EditModel::EditModel() : braces{} {
@@ -78,11 +80,28 @@ EditModel::~EditModel() {
 	pdoc = nullptr;
 }
 
-bool EditModel::BidirectionalEnabled() const {
+bool EditModel::BidirectionalEnabled() const noexcept {
 	return (bidirectional != Bidirectional::bidiDisabled) &&
 		(SC_CP_UTF8 == pdoc->dbcsCodePage);
 }
 
-bool EditModel::BidirectionalR2L() const {
+bool EditModel::BidirectionalR2L() const noexcept {
 	return bidirectional == Bidirectional::bidiR2L;
 }
+
+void EditModel::SetDefaultFoldDisplayText(const char *text) {
+	defaultFoldDisplayText = IsNullOrEmpty(text) ? UniqueString() : UniqueStringCopy(text);
+}
+
+const char *EditModel::GetDefaultFoldDisplayText() const noexcept {
+	return defaultFoldDisplayText.get();
+}
+
+const char *EditModel::GetFoldDisplayText(Sci::Line lineDoc) const {
+	if (foldDisplayTextStyle == SC_FOLDDISPLAYTEXT_HIDDEN || pcs->GetExpanded(lineDoc)) {
+		return nullptr;
+	}
+
+	const char *text = pcs->GetFoldDisplayText(lineDoc);
+	return text ? text : defaultFoldDisplayText.get();
+}
