@@ -6,6 +6,7 @@
 // The License.txt file describes the conditions under which this software may be distributed.
 
 #include <cstdlib>
+#include <cassert>
 #include <cstring>
 #include <cstdio>
 
@@ -13,13 +14,14 @@
 #include <vector>
 #include <memory>
 #include <chrono>
+#include <atomic>
+#include <mutex>
 
 #include "ILoader.h"
 
 #include "GUI.h"
 
 #include "FilePath.h"
-#include "Mutex.h"
 #include "Cookie.h"
 #include "Worker.h"
 #include "FileWorker.h"
@@ -51,7 +53,7 @@ void FileLoader::Execute() {
 		Utf8_16_Read convert;
 		std::vector<char> data(blockSize);
 		size_t lenFile = fread(&data[0], 1, blockSize, fp);
-		const UniMode umCodingCookie = CodingCookieValue(&data[0], lenFile);
+		const UniMode umCodingCookie = CodingCookieValue(std::string_view(data.data(), lenFile));
 		while ((lenFile > 0) && (err == 0) && (!Cancelling())) {
 			GUI::SleepMilliseconds(sleepTime);
 			lenFile = convert.convert(&data[0], lenFile);
