@@ -55,6 +55,15 @@ bool MarkerHandleSet::Contains(int handle) const noexcept {
 	return false;
 }
 
+MarkerHandleNumber const *MarkerHandleSet::GetMarkerHandleNumber(int which) const noexcept {
+	for (const MarkerHandleNumber &mhn : mhList) {
+		if (which == 0)
+			return &mhn;
+		which--;
+	}
+	return nullptr;
+}
+
 bool MarkerHandleSet::InsertHandle(int handle, int markerNum) {
 	mhList.push_front(MarkerHandleNumber(handle, markerNum));
 	return true;
@@ -76,7 +85,7 @@ bool MarkerHandleSet::RemoveNumber(int markerNum, bool all) {
 	return performedDeletion;
 }
 
-void MarkerHandleSet::CombineWith(MarkerHandleSet *other) {
+void MarkerHandleSet::CombineWith(MarkerHandleSet *other) noexcept {
 	mhList.splice_after(mhList.before_begin(), other->mhList);
 }
 
@@ -103,19 +112,31 @@ void LineMarkers::RemoveLine(Sci::Line line) {
 	}
 }
 
-Sci::Line LineMarkers::LineFromHandle(int markerHandle) {
-	if (markers.Length()) {
-		for (Sci::Line line = 0; line < markers.Length(); line++) {
-			if (markers[line]) {
-				if (markers[line]->Contains(markerHandle)) {
-					return line;
-				}
-			}
+Sci::Line LineMarkers::LineFromHandle(int markerHandle) const noexcept {
+	for (Sci::Line line = 0; line < markers.Length(); line++) {
+		if (markers[line] && markers[line]->Contains(markerHandle)) {
+			return line;
 		}
 	}
 	return -1;
 }
 
+int LineMarkers::HandleFromLine(Sci::Line line, int which) const noexcept {
+	if (markers.Length() && (line >= 0) && (line < markers.Length()) && markers[line]) {
+		MarkerHandleNumber const *pnmh = markers[line]->GetMarkerHandleNumber(which);
+		return pnmh ? pnmh->handle : -1;
+	}
+	return -1;
+}
+
+int LineMarkers::NumberFromLine(Sci::Line line, int which) const noexcept {
+	if (markers.Length() && (line >= 0) && (line < markers.Length()) && markers[line]) {
+		MarkerHandleNumber const *pnmh = markers[line]->GetMarkerHandleNumber(which);
+		return pnmh ? pnmh->number : -1;
+	}
+	return -1;
+}
+
 void LineMarkers::MergeMarkers(Sci::Line line) {
 	if (markers[line + 1]) {
 		if (!markers[line])
@@ -125,17 +146,17 @@ void LineMarkers::MergeMarkers(Sci::Line line) {
 	}
 }
 
-int LineMarkers::MarkValue(Sci::Line line) noexcept {
+int LineMarkers::MarkValue(Sci::Line line) const noexcept {
 	if (markers.Length() && (line >= 0) && (line < markers.Length()) && markers[line])
 		return markers[line]->MarkValue();
 	else
 		return 0;
 }
 
-Sci::Line LineMarkers::MarkerNext(Sci::Line lineStart, int mask) const {
+Sci::Line LineMarkers::MarkerNext(Sci::Line lineStart, int mask) const noexcept {
 	if (lineStart < 0)
 		lineStart = 0;
-	const Sci::Line length = static_cast<Sci::Line>(markers.Length());
+	const Sci::Line length = markers.Length();
 	for (Sci::Line iLine = lineStart; iLine < length; iLine++) {
 		const MarkerHandleSet *onLine = markers[iLine].get();
 		if (onLine && ((onLine->MarkValue() & mask) != 0))
@@ -205,7 +226,7 @@ void LineLevels::InsertLine(Sci::Line line) {
 void LineLevels::RemoveLine(Sci::Line line) {
 	if (levels.Length()) {
 		// Move up following lines but merge header flag from this line
-		// to line before to avoid a temporary disappearence causing expansion.
+		// to line before to avoid a temporary disappearance causing expansion.
 		int firstHeader = levels[line] & SC_FOLDLEVELHEADERFLAG;
 		levels.Delete(line);
 		if (line == levels.Length()-1) // Last line loses the header flag
@@ -237,7 +258,7 @@ int LineLevels::SetLevel(Sci::Line line, int level, Sci::Line lines) {
 	return prev;
 }
 
-int LineLevels::GetLevel(Sci::Line line) const {
+int LineLevels::GetLevel(Sci::Line line) const noexcept {
 	if (levels.Length() && (line >= 0) && (line < levels.Length())) {
 		return levels[line];
 	} else {
@@ -280,35 +301,34 @@ int LineState::GetLineState(Sci::Line line) {
 	return lineStates[line];
 }
 
-Sci::Line LineState::GetMaxLineState() const {
-	return static_cast<Sci::Line>(lineStates.Length());
-}
-
-static int NumberLines(const char *text) noexcept {
-	if (text) {
-		int newLines = 0;
-		while (*text) {
-			if (*text == '\n')
-				newLines++;
-			text++;
-		}
-		return newLines+1;
-	} else {
-		return 0;
-	}
+Sci::Line LineState::GetMaxLineState() const noexcept {
+	return lineStates.Length();
 }
 
 // Each allocated LineAnnotation is a char array which starts with an AnnotationHeader
 // and then has text and optional styles.
 
-static const int IndividualStyles = 0x100;
-
 struct AnnotationHeader {
 	short style;	// Style IndividualStyles implies array of styles
 	short lines;
 	int length;
 };
 
+namespace {
+
+constexpr int IndividualStyles = 0x100;
+
+size_t NumberLines(std::string_view sv) {
+	return std::count(sv.begin(), sv.end(), '\n') + 1;
+}
+
+std::unique_ptr<char[]>AllocateAnnotation(size_t length, int style) {
+	const size_t len = sizeof(AnnotationHeader) + length + ((style == IndividualStyles) ? length : 0);
+	return std::make_unique<char[]>(len);
+}
+
+}
+
 LineAnnotation::~LineAnnotation() {
 }
 
@@ -330,44 +350,39 @@ void LineAnnotation::RemoveLine(Sci::Line line) {
 	}
 }
 
-bool LineAnnotation::MultipleStyles(Sci::Line line) const {
+bool LineAnnotation::MultipleStyles(Sci::Line line) const noexcept {
 	if (annotations.Length() && (line >= 0) && (line < annotations.Length()) && annotations[line])
 		return reinterpret_cast<AnnotationHeader *>(annotations[line].get())->style == IndividualStyles;
 	else
 		return false;
 }
 
-int LineAnnotation::Style(Sci::Line line) const {
+int LineAnnotation::Style(Sci::Line line) const noexcept {
 	if (annotations.Length() && (line >= 0) && (line < annotations.Length()) && annotations[line])
 		return reinterpret_cast<AnnotationHeader *>(annotations[line].get())->style;
 	else
 		return 0;
 }
 
-const char *LineAnnotation::Text(Sci::Line line) const {
+const char *LineAnnotation::Text(Sci::Line line) const noexcept {
 	if (annotations.Length() && (line >= 0) && (line < annotations.Length()) && annotations[line])
 		return annotations[line].get()+sizeof(AnnotationHeader);
 	else
 		return nullptr;
 }
 
-const unsigned char *LineAnnotation::Styles(Sci::Line line) const {
+const unsigned char *LineAnnotation::Styles(Sci::Line line) const noexcept {
 	if (annotations.Length() && (line >= 0) && (line < annotations.Length()) && annotations[line] && MultipleStyles(line))
 		return reinterpret_cast<unsigned char *>(annotations[line].get() + sizeof(AnnotationHeader) + Length(line));
 	else
 		return nullptr;
 }
 
-static std::unique_ptr<char[]>AllocateAnnotation(int length, int style) {
-	const size_t len = sizeof(AnnotationHeader) + length + ((style == IndividualStyles) ? length : 0);
-	return std::make_unique<char[]>(len);
-}
-
 void LineAnnotation::SetText(Sci::Line line, const char *text) {
 	if (text && (line >= 0)) {
 		annotations.EnsureLength(line+1);
 		const int style = Style(line);
-		annotations[line] = AllocateAnnotation(static_cast<int>(strlen(text)), style);
+		annotations[line] = AllocateAnnotation(strlen(text), style);
 		char *pa = annotations[line].get();
 		assert(pa);
 		AnnotationHeader *pah = reinterpret_cast<AnnotationHeader *>(pa);
@@ -416,14 +431,14 @@ void LineAnnotation::SetStyles(Sci::Line line, const unsigned char *styles) {
 	}
 }
 
-int LineAnnotation::Length(Sci::Line line) const {
+int LineAnnotation::Length(Sci::Line line) const noexcept {
 	if (annotations.Length() && (line >= 0) && (line < annotations.Length()) && annotations[line])
 		return reinterpret_cast<AnnotationHeader *>(annotations[line].get())->length;
 	else
 		return 0;
 }
 
-int LineAnnotation::Lines(Sci::Line line) const {
+int LineAnnotation::Lines(Sci::Line line) const noexcept {
 	if (annotations.Length() && (line >= 0) && (line < annotations.Length()) && annotations[line])
 		return reinterpret_cast<AnnotationHeader *>(annotations[line].get())->lines;
 	else
@@ -451,7 +466,7 @@ void LineTabstops::RemoveLine(Sci::Line line) {
 	}
 }
 
-bool LineTabstops::ClearTabstops(Sci::Line line) {
+bool LineTabstops::ClearTabstops(Sci::Line line) noexcept {
 	if (line < tabstops.Length()) {
 		TabstopList *tl = tabstops[line].get();
 		if (tl) {
@@ -481,7 +496,7 @@ bool LineTabstops::AddTabstop(Sci::Line line, int x) {
 	return false;
 }
 
-int LineTabstops::GetNextTabstop(Sci::Line line, int x) const {
+int LineTabstops::GetNextTabstop(Sci::Line line, int x) const noexcept {
 	if (line < tabstops.Length()) {
 		TabstopList *tl = tabstops[line].get();
 		if (tl) {
