@@ -13,7 +13,7 @@
 void SciTEWin::SetFileProperties(
 	PropSetFile &ps) {			///< Property set to update.
 
-	const int TEMP_LEN = 100;
+	constexpr int TEMP_LEN = 100;
 	char temp[TEMP_LEN] = "";
 	HANDLE hf = ::CreateFileW(filePath.AsInternal(), GENERIC_READ, 0, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
 	if (hf != INVALID_HANDLE_VALUE) {
@@ -532,6 +532,8 @@ void SciTEWin::EnableAMenuItem(int wIDCheckItem, bool val) {
 }
 
 void SciTEWin::CheckMenus() {
+	if (!MainHWND())
+		return;
 	SciTEBase::CheckMenus();
 	::CheckMenuRadioItem(::GetMenu(MainHWND()), IDM_EOL_CRLF, IDM_EOL_LF,
 			     static_cast<int>(wEditor.EOLMode()) - static_cast<int>(SA::EndOfLine::CrLf) + IDM_EOL_CRLF, 0);
@@ -602,14 +604,6 @@ void SciTEWin::LocaliseDialog(HWND wDialog) {
 	}
 }
 
-// Mingw headers do not have this:
-#ifndef TBSTYLE_FLAT
-#define TBSTYLE_FLAT 0x0800
-#endif
-#ifndef TB_LOADIMAGES
-#define TB_LOADIMAGES (WM_USER + 50)
-#endif
-
 struct BarButton {
 	int id;
 	int cmd;
